@@ -15,6 +15,7 @@
 
 #include "netlink.h"
 #include "config.h"
+#include "includes.h"
 #include "log.h"
 #include "radvd.h"
 
@@ -22,7 +23,7 @@
 #include <errno.h>
 #include <linux/netlink.h>
 #include <linux/rtnetlink.h>
-#include <net/if.h>
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -43,7 +44,7 @@ int netlink_get_device_addr_len(struct Interface *iface)
 	struct iplink_req req = {};
 	struct iovec iov = {&req, sizeof(req)};
 	struct sockaddr_nl sa = {};
-	struct msghdr msg = {(void *)&sa, sizeof(sa), &iov, 1, NULL, 0, 0};
+	struct msghdr msg = {.msg_name=(void *)&sa, .msg_namelen=sizeof(sa), .msg_iov=&iov, .msg_iovlen=1, .msg_control=NULL, .msg_controllen=0, .msg_flags=0};
 	int sock, len, addr_len = -1;
 	unsigned short type;
 	char answer[32768];
@@ -99,7 +100,7 @@ void process_netlink_msg(int sock, struct Interface *ifaces)
 	char buf[4096];
 	struct iovec iov = {buf, sizeof(buf)};
 	struct sockaddr_nl sa;
-	struct msghdr msg = {(void *)&sa, sizeof(sa), &iov, 1, NULL, 0, 0};
+	struct msghdr msg = {.msg_name=(void *)&sa, .msg_namelen=sizeof(sa), .msg_iov=&iov, .msg_iovlen=1, .msg_control=NULL, .msg_controllen=0, .msg_flags=0};
 	int len = recvmsg(sock, &msg, 0);
 	if (len == -1) {
 		flog(LOG_ERR, "netlink: recvmsg failed: %s", strerror(errno));
